Source code and contacts
========================

Repository and bugs
~~~~~~~~~~~~~~~~~~~

The **source code** for this app is hosted on
https://github.com/shtalinberg/django-amp-tools.

To file **bugs and requests**, please use
https://github.com/shtalinberg/django-amp-tools/issues.

Contacts
~~~~~~~~

Oleksandr Shtalinberg

- Email: ``o.shtalinberg at gmail.com``
